# honorific

Данный пакет позволяет изменять форму обращения к человеку.
С неформальной ("ты") на более уважительную ("Вы"), и наоборот.

## Установка
Установка пакета
```bash
python -m pip install honorific
```
При первом запуске скачается пакет *ru_core_news_lg* для *spacy*, но можно установить его заранее

```bash
python -m spacy download ru_core_news_lg
```

## Пример

```python
>>> honorific.honor("Как твои дела?")
'Как ваши дела?'

>>> honorific.honor("Так ты скажешь, откуда ты?")
'Так вы скажете, откуда вы?'
```

## Описание

В данный момент обрабатываются 
* глаголы
* местоимения
* краткие прилагательные и причастия(+модальные глаголы).

## TODO
* обработка глаголов в прошедшем времени в СПП  
* обработка сложных конструкций(пропуск пунктуации и т.д)  
* обработка устойчивых выражений("ух ты" и т.д.)  
* обработка возвратно-притяжательных местоимений

# Метрики
* Gold Standart - соответствие проф. разметке = 100%
* Adequacy - соответствие нормам русского языка = 94%
* Accuracy - правильность измененных словоформ = 100%


